<?xml version="1.0" encoding="UTF-8"?>
<!-- FZ823v1.0_VALXSLT_492u2, 01-04-2021 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:fz823="http://ei.vektis.nl/fz/fz823"
xmlns:fz824="http://ei.vektis.nl/fz/fz824" >


	<xsl:import href="rc8028.xslt"/> 
	<xsl:import href="rc8986.xslt"/>
 	<xsl:import href="rc0350.xslt"/>	
 	<xsl:import href="rc0350a.xslt"/>	
  	<xsl:import href="rc9180.xslt"/>
	
  	
	<!-- Uitvoer is fz824 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
	
	<xsl:variable name="BerichtSoort" select="//fz823:Bericht/fz823:Header/fz823:BerichtSoort"/> 
	<xsl:variable name="Verzenddatum" select="translate(//fz823:Bericht/fz823:Header/fz823:Verzenddatum, '-', '')"/>

	<xsl:template match="//fz823:Bericht">
		<fz824:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/fz/fz824 fz824_493.xsd</xsl:attribute>
			<!-- Controleer op errors in de Header -->
				
			<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
			<xsl:variable name="rc8028">
				<xsl:call-template name="rc8028">
					<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
				</xsl:call-template>
			</xsl:variable>
				
			<!-- retourcode 8986: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
			<xsl:variable name="rc8986">
				<xsl:call-template name="rc8986">
					<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
					<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
				</xsl:call-template>
			</xsl:variable> 
			
			<xsl:choose>
				<!-- Geen errors in de Header, dan hele bericht als retour -->
				<xsl:when test="$rc8028='' and $rc8986=''">
					<xsl:apply-templates select="fz823:Header"/>
					<xsl:apply-templates select="fz823:Verzekerde"/>
				</xsl:when>
				<!-- Wel errors in de Header, dan alleen Header als retour -->
				<xsl:otherwise>
					<xsl:apply-templates select="fz823:Header"/>
				</xsl:otherwise>
			</xsl:choose>
				
		</fz824:Bericht>
	</xsl:template>	

	<xsl:template match="fz823:Header">
		<fz824:Header>
			<xsl:apply-templates select="fz823:BerichtSoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:Verzenddatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:AfzenderReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:JustitieleInstantie"/>
			<xsl:apply-templates select="fz823:Zorgaanbieder"/>
			<fz824:BerichtCode>493</fz824:BerichtCode>
			<xsl:apply-templates select="fz823:BerichtVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:BerichtSubVersie" mode="copy-if-exists"/>
			
  	       	<fz824:Retourcodes>
				
				<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
				<xsl:variable name="rc8028">
					<xsl:call-template name="rc8028">
						<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
					</xsl:call-template>
				</xsl:variable>
					
				<!-- retourcode 8920: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
				<xsl:variable name="rc8986">
					<xsl:call-template name="rc8986">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
						<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
					</xsl:call-template>
				</xsl:variable> 
					
				<xsl:copy-of select="$rc8028"/>
				<xsl:copy-of select="$rc8986"/>
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc8028='' and $rc8986=''">
					<fz824:Retourcode>0200</fz824:Retourcode>
				</xsl:if>
				
			</fz824:Retourcodes>
  	       	
		</fz824:Header>
	</xsl:template>
		
	<xsl:template match="fz823:Verzekerde">
		<fz824:Verzekerde>
			<xsl:apply-templates select="fz823:Verzekerdennummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:Geboortedatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:GeboortedatumOnbekend" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:StartForensischeZorg"/>
				
		  	<fz824:Retourcodes>	
				
				<!-- retourcode 0350: Geboortedatum moet kleiner zijn dan verzenddatum -->
				 <xsl:variable name="rc0350">
					
					<xsl:call-template name="rc0350">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
						<xsl:with-param name="Geboortedatum" select="translate(//fz823:Bericht/fz823:Verzekerde/fz823:Geboortedatum, '-', '')"/>
					</xsl:call-template>
				</xsl:variable> 
					
				<!-- retourcode 0350a: Geboortedatum moet bestaan als geboortedatumOnbekend = "false" -->
				 <xsl:variable name="rc0350a">
				
					<xsl:call-template name="rc0350a">
						<xsl:with-param name="GeboortedatumOnbekend" select="//fz823:Bericht/fz823:Verzekerde/fz823:GeboortedatumOnbekend"/>
						<xsl:with-param name="Geboortedatum" select="translate(//fz823:Bericht/fz823:Verzekerde/fz823:Geboortedatum, '-', '')"/>
					</xsl:call-template>
				</xsl:variable> 
					
				<xsl:copy-of select="$rc0350"/>
				<xsl:copy-of select="$rc0350a"/>
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc0350='' and $rc0350a=''">
					<fz824:Retourcode>0200</fz824:Retourcode>
				</xsl:if>
					
			</fz824:Retourcodes>			
			
		</fz824:Verzekerde>
	</xsl:template>		
		
	<xsl:template match="fz823:StartForensischeZorg">	
		<fz824:StartForensischeZorg>
			<xsl:apply-templates select="fz823:PlaatsingsbesluitNummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:PlaatsingsbesluitVolgnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:Startdatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:Locatie"/>
			
  	       	<fz824:Retourcodes>
				
				<!-- retourcode 9180: Startdatum Forensische zorg ontbreekt of is onjuist. -->
				<xsl:variable name="rc9180">
					<xsl:call-template name="rc9180">
						<xsl:with-param name="Startdatum" select="translate(//fz823:Bericht/fz823:Verzekerde/fz823:StartForensischeZorg/fz823:Startdatum, '-', '')"/>
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
					</xsl:call-template>
				</xsl:variable>
					
				<xsl:copy-of select="$rc9180"/>
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc9180=''">
					<fz824:Retourcode>0200</fz824:Retourcode>
				</xsl:if>
					
			</fz824:Retourcodes>			
			
		</fz824:StartForensischeZorg>
	</xsl:template>
		
	<xsl:template match="fz823:Locatie">	
		<fz823:Locatie>
			<xsl:apply-templates select="fz823:Ondernemingscode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:Vestigingscode" mode="copy-if-exists"/>
		</fz823:Locatie>
	</xsl:template>
			
		<xsl:template match="fz823:JustitieleInstantie">	
		<fz824:JustitieleInstantie>
			<xsl:apply-templates select="fz823:UZOVINummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:InstantieCode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:Naam"/>
			<xsl:apply-templates select="fz823:Voorletters" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:Emailadres" mode="copy-if-exists"/>
		</fz824:JustitieleInstantie>
	</xsl:template>
		
	<xsl:template match="fz823:Zorgaanbieder">	
		<fz824:Zorgaanbieder>
			<xsl:apply-templates select="fz823:Ondernemingscode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:Vestigingscode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:Emailadres" mode="copy-if-exists"/>
		</fz824:Zorgaanbieder>
	</xsl:template>
		
	<xsl:template match="fz823:Naam">	
		<fz823:Naam>
			<xsl:apply-templates select="fz823:Achternaam" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz823:Voorvoegsels" mode="copy-if-exists"/>
		</fz823:Naam>
	</xsl:template>
		
	<!-- Copy template: als een enkel element voorkomt is, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/fz/fz823']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat('fz824:',local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>